==> openjdk-17_17.0.11~7ea.orig.tar.xz: openjdk-17-17.0.11~7ea/test/langtools/tools/javac/patterns/Parenthesized.java <==
/*
 * Copyright (c) 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8262891 8269354
 * @summary Test parenthesized pattern
 * @compile --enable-preview -source ${jdk.version} Parenthesized.java
 * @run main/othervm --enable-preview Parenthesized
 */
public class Parenthesized {
    public static void main(String... args) {
        new Parenthesized().run();
    }

    void run() {
        Object o = "";
        switch (o) {
            case (String s && s.isEmpty()) -> System.err.println("OK: " + s);
            default -> throw new AssertionError();
        }
        System.err.println(switch (o) {
            case (String s && s.isEmpty()) -> "OK: " + s;
            default -> throw new AssertionError();
        });
        if (o instanceof (String s && s.isEmpty())) {
            System.err.println("OK: " + s);
        }
        boolean b1 = o instanceof (String s && s.isEmpty());
        boolean b2 = o instanceof String s && s.isEmpty();
    }

}

==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/langtools/tools/javac/patterns/Parenthesized.java <==
/*
 * Copyright (c) 2021, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 8262891 8269354
 * @summary Test parenthesized pattern
 * @compile --enable-preview -source ${jdk.version} Parenthesized.java
 * @run main/othervm --enable-preview Parenthesized
 */
public class Parenthesized {
    public static void main(String... args) {
        new Parenthesized().run();
    }

    void run() {
        Object o = "";
        switch (o) {
            case (String s) when s.isEmpty() -> System.err.println("OK: " + s);
            default -> throw new AssertionError();
        }
        System.err.println(switch (o) {
            case (String s) when s.isEmpty() -> "OK: " + s;
            default -> throw new AssertionError();
        });
        if (o instanceof (String s) && s.isEmpty()) {
            System.err.println("OK: " + s);
        }
        boolean b1 = o instanceof (String s) && s.isEmpty();
        boolean b2 = o instanceof String s && s.isEmpty();
    }

}
